@@ -33,7 +33,6 @@
 #  define KCMUTILSCORE_DECL_DEPRECATED_NO_EXPORT KCMUTILSCORE_NO_EXPORT KCMUTILSCORE_DECL_DEPRECATED
 #endif
 
-/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KCMUTILSCORE_NO_DEPRECATED
 #    define KCMUTILSCORE_NO_DEPRECATED
@@ -85,7 +84,7 @@
 #define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSCORE_NO_DEPRECATED
-#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -95,7 +94,7 @@
 #  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
